require("GUIS")

function love.load()
	Width,Height = love.graphics.getDimensions()

	Sun = {
		Longitude = GUIS.newLineairSlider("SunLongitude",120,45,280,15,-180,180,40),
		Latitude  = GUIS.newLineairSlider("SunLatitude" ,120,60,280,15,0,90,60),
		Size      = GUIS.newLineairSlider("SunSize"     ,120,75,280,15,0.01,10,1),
	}
	
	Sky = {
		Turbidity = GUIS.newLineairSlider("Turbidity"   ,120,105,280,15,1,16,2)
	}
	
	Render = {
		ResolutionX = 2000,
		ResolutionY = 1000
	}
	
	SkyCanvas      = love.graphics.newCanvas(Render.ResolutionX,Render.ResolutionY)
	SkyShader      = love.graphics.newShader("SkyModel.frag")

end

function RenderSky()
	SkyCanvas  = love.graphics.newCanvas(Render.ResolutionX,Render.ResolutionY)
	love.graphics.setCanvas(SkyCanvas)
		love.graphics.setShader(SkyShader)
			love.graphics.rectangle("fill",0,0,Render.ResolutionX,Render.ResolutionY)
		love.graphics.setShader()
	love.graphics.setCanvas()
end
	

function UpdateShader()
	SkyShader:send('iResolution',{Render.ResolutionX,Render.ResolutionY})

	SkyShader:send('sunLongitude'     ,Sun.Longitude.Value/180*math.pi)
	SkyShader:send('sunLatitude'      ,Sun.Latitude.Value/180*math.pi)
	SkyShader:send('sunSize'          ,Sun.Size.Value)
	
	SkyShader:send('turbidity'        ,Sky.Turbidity.Value)
end

function love.resize(w, h)
	print("Window resized to "..w..","..h)
	Width = w
	Height = h
end

function love.mousepressed(x,y,button)
	GUIS:mousepressed(x,y,button)
end

function love.mousemoved(x,y,dx,dy)
	GUIS:mousemoved(x,y,dx,dy)
end

function love.mousereleased(x,y,button)
	GUIS:mousereleased(x,y,button)
end

function love.keypressed(key, scancode)
	if scancode == "b" then
		SkyCanvas:newImageData():encode('png', os.time() .. '.png');
		
		print("Screenshot taking!")
	end
end

function love.update(dt)
	UpdateShader()
	
	if (love.keyboard.isDown("space")) then
		RenderSky()
	end
end


function love.draw()

	local scale = math.min(Width/Render.ResolutionX,Height/Render.ResolutionY)
	love.graphics.draw(SkyCanvas,Width/2.,Height/2.,0,scale,scale,Render.ResolutionX/2,Render.ResolutionY/2)

	--extra info
	love.graphics.setColor(0,0,0)
	love.graphics.rectangle("fill",0,0,400,120)
	love.graphics.setColor(255,255,255)

	love.graphics.print("hold 'space' to render",0,15)
	
	love.graphics.print("Sun Longitude : ",0,45)
	love.graphics.print("Sun Latitude : ",0,60)
	love.graphics.print("Sun Size : ",0,75)
	
	love.graphics.print("Sky Turbidity : ",0,105)
	
	GUIS:draw()

end